@@ -6,7 +6,8 @@ module RailsI18n
 
       def self.rule
         lambda do |n|
-          n ||= 0
+          return :other unless n.is_a?(Numeric)
+
           frac = (n.to_d % 1)
 
           if frac.nonzero?
