@@ -3,7 +3,8 @@ module RailsI18n
     module Arabic
       def self.rule
         lambda do |n|
-          n ||= 0
+          return :other unless n.is_a?(Numeric)
+
           mod100 = n % 100
 
           if n == 0
@@ -29,4 +30,4 @@ end
     :'i18n' => {
       :plural => {
         :keys => [:zero, :one, :two, :few, :many, :other],
-        :rule => RailsI18n::Pluralization::Arabic.rule }}}}
\ No newline at end of file
+        :rule => RailsI18n::Pluralization::Arabic.rule }}}}
