@@ -3,11 +3,15 @@ module RailsI18n
     module ScottishGaelic
       def self.rule
         lambda do |n|
-          if n == 1 || n == 11
+          return :other unless n.is_a?(Numeric)
+
+          floorn = n.floor
+
+          if floorn == 1 || floorn == 11
             :one
-          elsif n == 2 || n == 12
+          elsif floorn == 2 || floorn == 12
             :two
-          elsif ((3..10).to_a + (13..19).to_a).include?(n)
+          elsif (3..19).member?(floorn)
             :few
           else
             :other
@@ -22,4 +26,4 @@ end
     :'i18n' => {
       :plural => {
         :keys => [:one, :two, :few, :other],
-        :rule => RailsI18n::Pluralization::ScottishGaelic.rule }}}}
\ No newline at end of file
+        :rule => RailsI18n::Pluralization::ScottishGaelic.rule }}}}
