@@ -3,8 +3,7 @@ module RailsI18n
     module Macedonian
       def self.rule
         lambda do |n|
-          n ||= 0
-          if n % 10 == 1 && n != 11
+          if n.is_a?(Numeric) && n % 10 == 1 && n != 11
             :one
           else
             :other
@@ -19,4 +18,4 @@ end
     :'i18n' => {
       :plural => {
         :keys => [:one, :other],
-        :rule => RailsI18n::Pluralization::Macedonian.rule }}}}
\ No newline at end of file
+        :rule => RailsI18n::Pluralization::Macedonian.rule }}}}
